"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const connections_1 = require("../../lib/connections");
class Login extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Login);
        try {
            const { id = "", baseUrl = "", userName = "", password = "" } = args;
            const { client, "skip-ssl-validation": nosslvalidation, certPath } = flags;
            connections_1.saveConnection({
                id,
                baseUrl,
                userName,
                password,
                certPath,
                client,
                nosslvalidation
            });
            this.log(`Connection ${id} created/updated`);
        }
        catch (error) {
            this.log(error.toString());
        }
    }
}
exports.default = Login;
Login.description = "Store the server and user details";
Login.examples = [
    "$ abapPretty connection:create MYCONN https://myserver:44300 myuser mypass --certPath=/secret/cert"
];
Login.args = [
    {
        name: "id",
        required: true,
        description: "connection ID"
    },
    {
        name: "baseUrl",
        required: true,
        description: "Server base URL"
    },
    {
        name: "userName",
        required: true,
        description: "Username"
    },
    {
        name: "password",
        description: "User password. If not set will be asked on use",
        required: false
    }
];
Login.flags = {
    client: command_1.flags.string({
        char: "C",
        description: "SAP client to connect to"
    }),
    "skip-ssl-validation": command_1.flags.boolean({
        char: "s",
        default: false,
        description: "Don't validate SSL certificate - DANGEROUS"
    }),
    certPath: command_1.flags.string({
        description: "Path to SSL certificate"
    })
};
