"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const common_1 = require("../lib/common");
const cli_ux_1 = require("cli-ux");
const abap_1 = require("../lib/abap");
class List extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(List);
        try {
            const { objectType = "", objectName = "" } = args;
            const client = await common_1.getClient(flags);
            const objects = await abap_1.list(client, objectType, objectName, message => cli_ux_1.cli.action.start(message), flags.recursive);
            cli_ux_1.cli.action.stop("Done");
            cli_ux_1.cli.table(objects, {
                type: {},
                name: {},
                url: {}
            });
        }
        catch (error) {
            this.log(error.toString());
        }
    }
}
exports.default = List;
List.description = "List objects that would be updated";
List.examples = [
    "$ abapPretty list -c MYCONN DEVC/K ZMYPACKAGE",
    "$ abapPretty list -h host -P port -u user -p password DEVC/K ZMYPACKAGE",
    `$ SAP_ASHOST=host SAP_PORT=port SAP_USER=user SAP_PASSWORD=bash -c 'abapPretty list DEVC/K ZMYPACKAGE'`
];
List.flags = common_1.COMMONFLAGS;
List.args = common_1.COMMONARGS;
List.strict = false;
