"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const connections_1 = require("./connections");
const cli_ux_1 = require("cli-ux");
const abap_adt_api_1 = require("abap-adt-api");
exports.ABAPLINT_DEFAULT = "<default>";
exports.RECURSIVEFLAG = {
    recursive: command_1.flags.boolean({
        char: "r",
        description: "Expand subpackages",
        default: false
    })
};
const PPONLYFLAGS = {
    transport: command_1.flags.string({
        char: "t",
        description: "Transport",
        default: ""
    }),
    abaplint: command_1.flags.string({
        char: "a",
        description: `Format using abapLint config file.\nIf left blank or set to ${exports.ABAPLINT_DEFAULT} the default configuration will be used`,
        parse: x => x || exports.ABAPLINT_DEFAULT
    }),
    file: command_1.flags.string({
        char: "f",
        description: "File with a list of objects to process",
        default: ""
    })
};
const LOGINOPTS = {
    connectionId: command_1.flags.string({
        char: "c",
        required: false,
        description: "connection ID"
    }),
    ashost: command_1.flags.string({
        char: "h",
        description: "SAP hostname",
        env: "SAP_ASHOST"
    }),
    port: command_1.flags.integer({
        char: "P",
        description: "Port to connect to",
        env: "SAP_PORT"
    }),
    user: command_1.flags.string({ char: "u", description: "Username", env: "SAP_USER" }),
    client: command_1.flags.string({
        char: "C",
        description: "SAP client to connect to",
        env: "SAP_CLIENT"
    }),
    ssl: command_1.flags.boolean({
        default: true,
        description: "use SSL (default)",
        allowNo: true
    }),
    "skip-ssl-validation": command_1.flags.string({
        char: "s",
        description: "Don't validate SSL certificate - DANGEROUS"
    }),
    certPath: command_1.flags.string({
        description: "Path to SSL certificate",
        env: "SAP_SSL_SERVER_CERT"
    }),
    password: command_1.flags.string({
        char: "p",
        description: "Password",
        env: "SAP_PASSWORD",
        default: ""
    })
};
exports.COMMONFLAGS = Object.assign(Object.assign({}, exports.RECURSIVEFLAG), LOGINOPTS);
exports.ALLCOMMONFLAGS = Object.assign(Object.assign({}, exports.COMMONFLAGS), PPONLYFLAGS);
exports.COMMONARGS = [
    {
        name: "objectType",
        required: false,
        default: "",
        description: "Base object type"
    },
    {
        name: "objectName",
        required: false,
        default: "",
        description: "Base object name"
    }
];
async function getClientInt(data) {
    var _a;
    if (data.ashost && data.port) {
        if (!data.user || !data.password)
            cli_ux_1.cli.error("User and password are mandatory unless using connectionIds");
        const nossl = !data.ssl || ((_a = process.env.SAP_SSL) === null || _a === void 0 ? void 0 : _a.match(/^no|off|false$/i));
        const nosslValid = data["skip-ssl-validation"] || process.env.SAP_SSL_VERIFY === "no";
        const config = abap_adt_api_1.createSSLConfig(!!nosslValid, data.certPath);
        return new abap_adt_api_1.ADTClient(`http${nossl ? "" : "s"}://${data.ashost}:${data.port}`, data.user, data.password, data.client, undefined, config);
    }
    if (!data.connectionId)
        cli_ux_1.cli.error("No connection details provided");
    const conn = connections_1.getConnection(data.connectionId);
    if (!conn)
        cli_ux_1.cli.error(`Invalid connection id ${data.connectionId}`);
    const password = data.password ||
        conn.password ||
        (await cli_ux_1.cli.prompt(`Password for user ${conn.userName} on ${conn.baseUrl}`, {
            type: "hide"
        }));
    const config = abap_adt_api_1.createSSLConfig(!!conn.nosslvalidation, conn.certPath);
    return new abap_adt_api_1.ADTClient(conn.baseUrl, conn.userName, password, data.client, undefined, config);
}
async function getClient(data) {
    const client = await getClientInt(data);
    await client.login(); // trigger connection errror on bad details
    return client;
}
exports.getClient = getClient;
